Cleaned up checkstyle errors
Removed $Id$ from files.
diff --git a/src/main/java/org/apache/maven/plugins/dependency/AbstractDependencyMojo.java b/src/main/java/org/apache/maven/plugins/dependency/AbstractDependencyMojo.java
index dc89a6b..43a0f6f 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/AbstractDependencyMojo.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/AbstractDependencyMojo.java
@@ -48,7 +48,6 @@
 
 /**
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
- * @version $Id$
  */
 public abstract class AbstractDependencyMojo
     extends AbstractMojo
@@ -144,6 +143,10 @@
         doExecute();
     }
 
+    /**
+     * @throws MojoExecutionException {@link MojoExecutionException}
+     * @throws MojoFailureException {@link MojoFailureException}
+     */
     protected abstract void doExecute()
         throws MojoExecutionException, MojoFailureException;
 
@@ -186,6 +189,12 @@
         }
     }
 
+    /**
+     * @param artifact {@link Artifact}
+     * @param location The location.
+     * @param encoding The encoding.
+     * @throws MojoExecutionException in case of an error.
+     */
     protected void unpack( Artifact artifact, File location, String encoding )
         throws MojoExecutionException
     {
@@ -210,6 +219,15 @@
         unpack( artifact, artifact.getType(), location, includes, excludes, encoding );
     }
 
+    /**
+     * @param artifact {@link Artifact}
+     * @param type The type.
+     * @param location The location.
+     * @param includes includes list.
+     * @param excludes excludes list.
+     * @param encoding the encoding.
+     * @throws MojoExecutionException in case of an error.
+     */
     protected void unpack( Artifact artifact, String type, File location, String includes, String excludes,
                            String encoding )
         throws MojoExecutionException
@@ -345,31 +363,49 @@
         this.archiverManager = archiverManager;
     }
 
+    /**
+     * @return {@link #useJvmChmod}
+     */
     public boolean isUseJvmChmod()
     {
         return useJvmChmod;
     }
 
+    /**
+     * @param useJvmChmod {@link #useJvmChmod}
+     */
     public void setUseJvmChmod( boolean useJvmChmod )
     {
         this.useJvmChmod = useJvmChmod;
     }
 
+    /**
+     * @return {@link #skip}
+     */
     public boolean isSkip()
     {
         return skip;
     }
 
+    /**
+     * @param skip {@link #skip}
+     */
     public void setSkip( boolean skip )
     {
         this.skip = skip;
     }
 
+    /**
+     * @return {@link #silent}
+     */
     protected final boolean isSilent()
     {
         return silent;
     }
 
+    /**
+     * @param silent {@link #silent}
+     */
     public void setSilent( boolean silent )
     {
         this.silent = silent;
diff --git a/src/main/java/org/apache/maven/plugins/dependency/GetMojo.java b/src/main/java/org/apache/maven/plugins/dependency/GetMojo.java
index 0dda115..a734f94 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/GetMojo.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/GetMojo.java
@@ -290,36 +290,49 @@
         return layout;
     }
 
+    /**
+     * @return {@link #skip}
+     */
     protected boolean isSkip()
     {
         return skip;
     }
 
-    // @Parameter( alias = "groupId" )
+    /**
+     * @param groupId The groupId.
+     */
     public void setGroupId( String groupId )
     {
         this.coordinate.setGroupId( groupId );
     }
 
-    // @Parameter( alias = "artifactId" )
+    /**
+     * @param artifactId The artifactId.
+     */
     public void setArtifactId( String artifactId )
     {
         this.coordinate.setArtifactId( artifactId );
     }
 
-    // @Parameter( alias = "version" )
+    /**
+     * @param version The version.
+     */
     public void setVersion( String version )
     {
         this.coordinate.setVersion( version );
     }
 
-    // @Parameter( alias = "classifier" )
+    /**
+     * @param classifier The classifier to be used.
+     */
     public void setClassifier( String classifier )
     {
         this.coordinate.setClassifier( classifier );
     }
 
-    // @Parameter( alias = "packaging" )
+    /**
+     * @param type packaging.
+     */
     public void setPackaging( String type )
     {
         this.coordinate.setType( type );
diff --git a/src/main/java/org/apache/maven/plugins/dependency/PropertiesMojo.java b/src/main/java/org/apache/maven/plugins/dependency/PropertiesMojo.java
index 7c28a81..2961599 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/PropertiesMojo.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/PropertiesMojo.java
@@ -36,7 +36,6 @@
  * and contains the path to the resolved artifact.
  *
  * @author Paul Gier
- * @version $Id$
  * @since 2.2
  */
 //CHECKSTYLE_OFF: LineLength
@@ -84,6 +83,9 @@
         }
     }
 
+    /**
+     * @return {@link #skip}
+     */
     public boolean isSkip()
     {
         return skip;
diff --git a/src/main/java/org/apache/maven/plugins/dependency/analyze/AbstractAnalyzeMojo.java b/src/main/java/org/apache/maven/plugins/dependency/analyze/AbstractAnalyzeMojo.java
index e2ce7cf..0e0f584 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/analyze/AbstractAnalyzeMojo.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/analyze/AbstractAnalyzeMojo.java
@@ -52,7 +52,6 @@
  * and declared.
  *
  * @author <a href="mailto:markhobson@gmail.com">Mark Hobson</a>
- * @version $Id$
  * @since 2.0-alpha-5
  */
 public abstract class AbstractAnalyzeMojo
@@ -255,6 +254,10 @@
         }
     }
 
+    /**
+     * @return {@link ProjectDependencyAnalyzer}
+     * @throws MojoExecutionException in case of an error.
+     */
     protected ProjectDependencyAnalyzer createProjectDependencyAnalyzer()
         throws MojoExecutionException
     {
@@ -276,12 +279,15 @@
     }
 
     @Override
-    public void contextualize( Context context )
+    public void contextualize( Context theContext )
         throws ContextException
     {
-        this.context = context;
+        this.context = theContext;
     }
 
+    /**
+     * @return {@link #skip}
+     */
     protected final boolean isSkip()
     {
         return skip;
diff --git a/src/main/java/org/apache/maven/plugins/dependency/analyze/AnalyzeDepMgt.java b/src/main/java/org/apache/maven/plugins/dependency/analyze/AnalyzeDepMgt.java
index dc8bb61..3fa1a0e 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/analyze/AnalyzeDepMgt.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/analyze/AnalyzeDepMgt.java
@@ -47,7 +47,6 @@
  * false to detect these otherwise normal conditions.
  *
  * @author <a href="mailto:brianefox@gmail.com">Brian Fox</a>
- * @version $Id$
  * @since 2.0-alpha-3
  */
 @Mojo( name = "analyze-dep-mgt", requiresDependencyResolution = ResolutionScope.TEST, threadSafe = true )
@@ -230,11 +229,19 @@
         return list;
     }
 
+    /**
+     * @param artifact {@link Artifact}
+     * @return The resulting GA.
+     */
     public String getExclusionKey( Artifact artifact )
     {
         return artifact.getGroupId() + ":" + artifact.getArtifactId();
     }
 
+    /**
+     * @param ex The exclusion key.
+     * @return The resulting combination of groupId+artifactId.
+     */
     public String getExclusionKey( Exclusion ex )
     {
         return ex.getGroupId() + ":" + ex.getArtifactId();
diff --git a/src/main/java/org/apache/maven/plugins/dependency/analyze/AnalyzeDuplicateMojo.java b/src/main/java/org/apache/maven/plugins/dependency/analyze/AnalyzeDuplicateMojo.java
index 59a16ce..e1260d4 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/analyze/AnalyzeDuplicateMojo.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/analyze/AnalyzeDuplicateMojo.java
@@ -45,7 +45,6 @@
  * <code>pom.xml</code> and determines the duplicate declared dependencies.
  *
  * @author <a href="mailto:vincent.siveton@gmail.com">Vincent Siveton</a>
- * @version $Id$
  */
 @Mojo( name = "analyze-duplicate", aggregator = false, threadSafe = true )
 public class AnalyzeDuplicateMojo
diff --git a/src/main/java/org/apache/maven/plugins/dependency/analyze/AnalyzeMojo.java b/src/main/java/org/apache/maven/plugins/dependency/analyze/AnalyzeMojo.java
index ef8e04a..2bd4341 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/analyze/AnalyzeMojo.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/analyze/AnalyzeMojo.java
@@ -35,7 +35,6 @@
  * </p>
  *
  * @author <a href="mailto:markhobson@gmail.com">Mark Hobson</a>
- * @version $Id$
  * @see AnalyzeOnlyMojo
  * @since 2.0-alpha-3
  */
diff --git a/src/main/java/org/apache/maven/plugins/dependency/analyze/AnalyzeOnlyMojo.java b/src/main/java/org/apache/maven/plugins/dependency/analyze/AnalyzeOnlyMojo.java
index f095ef5..0265661 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/analyze/AnalyzeOnlyMojo.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/analyze/AnalyzeOnlyMojo.java
@@ -35,7 +35,6 @@
  * </p>
  *
  * @author <a href="mailto:markhobson@gmail.com">Mark Hobson</a>
- * @version $Id$
  * @see AnalyzeMojo
  * @since 2.0
  */
diff --git a/src/main/java/org/apache/maven/plugins/dependency/analyze/AnalyzeReportMojo.java b/src/main/java/org/apache/maven/plugins/dependency/analyze/AnalyzeReportMojo.java
index 5e5fe56..3d39533 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/analyze/AnalyzeReportMojo.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/analyze/AnalyzeReportMojo.java
@@ -42,7 +42,6 @@
  * Analyzes the dependencies of this project and produces a report that summarizes which are: used and declared; used
  * and undeclared; unused and declared.
  *
- * @version $Id$
  * @since 2.0-alpha-5
  */
 @Mojo( name = "analyze-report", requiresDependencyResolution = ResolutionScope.TEST, threadSafe = true )
diff --git a/src/main/java/org/apache/maven/plugins/dependency/fromConfiguration/AbstractFromConfigurationMojo.java b/src/main/java/org/apache/maven/plugins/dependency/fromConfiguration/AbstractFromConfigurationMojo.java
index 18236ca..3bebdee 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/fromConfiguration/AbstractFromConfigurationMojo.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/fromConfiguration/AbstractFromConfigurationMojo.java
@@ -48,7 +48,6 @@
  * ArtifactItems
  *
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
- * @version $Id$
  * @see ArtifactItem
  */
 public abstract class AbstractFromConfigurationMojo
@@ -115,7 +114,11 @@
 
     abstract ArtifactItemFilter getMarkedArtifactFilter( ArtifactItem item );
 
-    // artifactItems is filled by either field injection or by setArtifact()
+    /**
+     * artifactItems is filled by either field injection or by setArtifact().
+     * 
+     * @throws MojoFailureException in case of an error.
+     */
     protected void verifyRequirements()
         throws MojoFailureException
     {
@@ -388,11 +391,18 @@
         this.overWriteSnapshots = theOverWriteSnapshots;
     }
 
+    /**
+     * @param localRepositoryDirectory {@link #localRepositoryDirectory}
+     */
     public void setLocalRepositoryDirectory( File localRepositoryDirectory )
     {
         this.localRepositoryDirectory = localRepositoryDirectory;
     }
 
+    /**
+     * @param artifact The artifact.
+     * @throws MojoFailureException in case of an error.
+     */
     public void setArtifact( String artifact )
         throws MojoFailureException
     {
diff --git a/src/main/java/org/apache/maven/plugins/dependency/fromConfiguration/CopyMojo.java b/src/main/java/org/apache/maven/plugins/dependency/fromConfiguration/CopyMojo.java
index b8120a1..a2f2d35 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/fromConfiguration/CopyMojo.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/fromConfiguration/CopyMojo.java
@@ -34,7 +34,6 @@
  * Goal that copies a list of artifacts from the repository to defined locations.
  *
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
- * @version $Id$
  * @since 1.0
  */
 @Mojo( name = "copy", defaultPhase = LifecyclePhase.PROCESS_SOURCES, requiresProject = false, threadSafe = true )
diff --git a/src/main/java/org/apache/maven/plugins/dependency/fromConfiguration/ProcessArtifactItemsRequest.java b/src/main/java/org/apache/maven/plugins/dependency/fromConfiguration/ProcessArtifactItemsRequest.java
index 6129348..0e27b55 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/fromConfiguration/ProcessArtifactItemsRequest.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/fromConfiguration/ProcessArtifactItemsRequest.java
@@ -45,11 +45,20 @@
      */
     private boolean useBaseVersion;
 
+    /**
+     * Default ctor.
+     */
     public ProcessArtifactItemsRequest()
     {
         // no op
     }
 
+    /**
+     * @param removeVersion {@link #removeVersion}
+     * @param prependGroupId {@link #prependGroupId}
+     * @param useBaseVersion {@link #useBaseVersion}
+     * @param removeClassifier {@link #removeClassifier}
+     */
     public ProcessArtifactItemsRequest( boolean removeVersion, boolean prependGroupId, boolean useBaseVersion,
                                         boolean removeClassifier )
     {
@@ -59,61 +68,97 @@
         this.removeClassifier = removeClassifier;
     }
 
+    /**
+     * @return {@link #removeVersion}
+     */
     public boolean isRemoveVersion()
     {
         return removeVersion;
     }
 
+    /**
+     * @param removeVersion {@link #removeVersion}
+     */
     public void setRemoveVersion( boolean removeVersion )
     {
         this.removeVersion = removeVersion;
     }
 
+    /**
+     * @return {@link #removeClassifier}
+     */
     public boolean isRemoveClassifier()
     {
         return removeClassifier;
     }
 
+    /**
+     * @param removeClassifier {@link #removeClassifier}
+     */
     public void setRemoveClassifier( boolean removeClassifier )
     {
         this.removeClassifier = removeClassifier;
     }
 
-    public ProcessArtifactItemsRequest removeVersion( boolean removeVersion )
+    /**
+     * @param theRemoveVersion {@link #removeVersion}
+     * @return {@link ProcessArtifactItemsRequest}
+     */
+    public ProcessArtifactItemsRequest removeVersion( boolean theRemoveVersion )
     {
-        this.removeVersion = removeVersion;
+        this.removeVersion = theRemoveVersion;
         return this;
     }
 
+    /**
+     * @return {@link #prependGroupId}
+     */
     public boolean isPrependGroupId()
     {
         return prependGroupId;
     }
 
+    /**
+     * @param prependGroupId {@link #prependGroupId}
+     */
     public void setPrependGroupId( boolean prependGroupId )
     {
         this.prependGroupId = prependGroupId;
     }
 
-    public ProcessArtifactItemsRequest prependGroupId( boolean prependGroupId )
+    /**
+     * @param thePrependGroupId {@link #prependGroupId}
+     * @return {@link ProcessArtifactItemsRequest}
+     */
+    public ProcessArtifactItemsRequest prependGroupId( boolean thePrependGroupId )
     {
-        this.prependGroupId = prependGroupId;
+        this.prependGroupId = thePrependGroupId;
         return this;
     }
 
+    /**
+     * @return {@link #useBaseVersion}
+     */
     public boolean isUseBaseVersion()
     {
         return useBaseVersion;
     }
 
+    /**
+     * @param useBaseVersion {@link #useBaseVersion}
+     */
     public void setUseBaseVersion( boolean useBaseVersion )
     {
         this.useBaseVersion = useBaseVersion;
     }
 
-    public ProcessArtifactItemsRequest useBaseVersion( boolean useBaseVersion )
+    /**
+     * @param theUseBaseVersion {@link #useBaseVersion}
+     * @return {@link ProcessArtifactItemsRequest}
+     */
+    public ProcessArtifactItemsRequest useBaseVersion( boolean theUseBaseVersion )
     {
-        this.useBaseVersion = useBaseVersion;
+        this.useBaseVersion = theUseBaseVersion;
         return this;
     }
 }
diff --git a/src/main/java/org/apache/maven/plugins/dependency/fromConfiguration/UnpackMojo.java b/src/main/java/org/apache/maven/plugins/dependency/fromConfiguration/UnpackMojo.java
index 8a62cfb..3cc3d66 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/fromConfiguration/UnpackMojo.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/fromConfiguration/UnpackMojo.java
@@ -37,7 +37,6 @@
  * Goal that retrieves a list of artifacts from the repository and unpacks them in a defined location.
  *
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
- * @version $Id$
  * @since 1.0
  */
 @Mojo( name = "unpack", defaultPhase = LifecyclePhase.PROCESS_SOURCES, requiresProject = false, threadSafe = true )
@@ -140,6 +139,11 @@
                                      handler );
     }
 
+    /**
+     * @param removeVersion removeVersion.
+     * @return list of {@link ArtifactItem}
+     * @throws MojoExecutionException in case of an error.
+     */
     protected List<ArtifactItem> getProcessedArtifactItems( boolean removeVersion )
         throws MojoExecutionException
     {
diff --git a/src/main/java/org/apache/maven/plugins/dependency/fromDependencies/AbstractDependencyFilterMojo.java b/src/main/java/org/apache/maven/plugins/dependency/fromDependencies/AbstractDependencyFilterMojo.java
index 4efd105..ae68cb3 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/fromDependencies/AbstractDependencyFilterMojo.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/fromDependencies/AbstractDependencyFilterMojo.java
@@ -59,7 +59,6 @@
  * Class that encapsulates the plugin parameters, and contains methods that handle dependency filtering
  *
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
- * @version $Id$
  * @see org.apache.maven.plugins.dependency.AbstractDependencyMojo
  */
 public abstract class AbstractDependencyFilterMojo
@@ -526,16 +525,25 @@
         this.prependGroupId = prependGroupId;
     }
 
+    /**
+     * @return {@link #artifactResolver}
+     */
     protected final ArtifactResolver getArtifactResolver()
     {
         return artifactResolver;
     }
 
+    /**
+     * @return {@link #dependencyResolver}
+     */
     protected final DependencyResolver getDependencyResolver()
     {
         return dependencyResolver;
     }
 
+    /**
+     * @return {@link #repositoryManager}
+     */
     protected final RepositoryManager getRepositoryManager()
     {
         return repositoryManager;
diff --git a/src/main/java/org/apache/maven/plugins/dependency/fromDependencies/AbstractFromDependenciesMojo.java b/src/main/java/org/apache/maven/plugins/dependency/fromDependencies/AbstractFromDependenciesMojo.java
index bbd9508..8de1c07 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/fromDependencies/AbstractFromDependenciesMojo.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/fromDependencies/AbstractFromDependenciesMojo.java
@@ -27,7 +27,6 @@
  * Abstract Parent class used by mojos that get Artifact information from the project dependencies.
  *
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
- * @version $Id$
  */
 public abstract class AbstractFromDependenciesMojo
     extends AbstractDependencyFilterMojo
@@ -166,21 +165,33 @@
         this.useSubDirectoryPerType = theUseSubDirectoryPerType;
     }
 
+    /**
+     * @return {@link #failOnMissingClassifierArtifact}
+     */
     public boolean isFailOnMissingClassifierArtifact()
     {
         return failOnMissingClassifierArtifact;
     }
 
+    /**
+     * @param failOnMissingClassifierArtifact {@link #failOnMissingClassifierArtifact}
+     */
     public void setFailOnMissingClassifierArtifact( boolean failOnMissingClassifierArtifact )
     {
         this.failOnMissingClassifierArtifact = failOnMissingClassifierArtifact;
     }
 
+    /**
+     * @return {@link #stripVersion}
+     */
     public boolean isStripVersion()
     {
         return stripVersion;
     }
 
+    /**
+     * @param stripVersion {@link #stripVersion}
+     */
     public void setStripVersion( boolean stripVersion )
     {
         this.stripVersion = stripVersion;
diff --git a/src/main/java/org/apache/maven/plugins/dependency/fromDependencies/BuildClasspathMojo.java b/src/main/java/org/apache/maven/plugins/dependency/fromDependencies/BuildClasspathMojo.java
index 3f356e1..d6458b3 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/fromDependencies/BuildClasspathMojo.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/fromDependencies/BuildClasspathMojo.java
@@ -52,7 +52,6 @@
  * This goal will output a classpath string of dependencies from the local repository to a file or log.
  *
  * @author ankostis
- * @version $Id$
  * @since 2.0-alpha-2
  */
 // CHECKSTYLE_OFF: LineLength
@@ -255,6 +254,10 @@
         }
     }
 
+    /**
+     * @param cpString The classpath.
+     * @throws MojoExecutionException in case of an error.
+     */
     protected void attachFile( String cpString )
         throws MojoExecutionException
     {
@@ -493,6 +496,9 @@
         this.stripVersion = theStripVersion;
     }
 
+    /**
+     * @param localRepoProperty {@link #localRepoProperty}
+     */
     public void setLocalRepoProperty( String localRepoProperty )
     {
         this.localRepoProperty = localRepoProperty;
diff --git a/src/main/java/org/apache/maven/plugins/dependency/fromDependencies/UnpackDependenciesMojo.java b/src/main/java/org/apache/maven/plugins/dependency/fromDependencies/UnpackDependenciesMojo.java
index 0e40a98..85c0c27 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/fromDependencies/UnpackDependenciesMojo.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/fromDependencies/UnpackDependenciesMojo.java
@@ -37,7 +37,6 @@
  * Goal that unpacks the project dependencies from the repository to a defined location.
  *
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
- * @version $Id$
  * @since 1.0
  */
 //CHECKSTYLE_OFF: LineLength
diff --git a/src/main/java/org/apache/maven/plugins/dependency/resolvers/AbstractResolveMojo.java b/src/main/java/org/apache/maven/plugins/dependency/resolvers/AbstractResolveMojo.java
index 160336e..8e50105 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/resolvers/AbstractResolveMojo.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/resolvers/AbstractResolveMojo.java
@@ -40,7 +40,6 @@
 
 /**
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
- * @version $Id$
  */
 public abstract class AbstractResolveMojo
     extends AbstractDependencyFilterMojo
@@ -92,6 +91,9 @@
     @Parameter
     protected boolean ignorePermissions;
 
+    /**
+     * @return {@link FilterArtifacts}
+     */
     protected FilterArtifacts getPluginArtifactsFilter()
     {
         if ( excludeReactor )
diff --git a/src/main/java/org/apache/maven/plugins/dependency/resolvers/CollectDependenciesMojo.java b/src/main/java/org/apache/maven/plugins/dependency/resolvers/CollectDependenciesMojo.java
index 123347f..98152a7 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/resolvers/CollectDependenciesMojo.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/resolvers/CollectDependenciesMojo.java
@@ -39,7 +39,6 @@
  *
  * @author <a href="mailto:epabst@gmail.com">Eric Pabst</a>
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
- * @version $Id$
  * @since 3.0
  */
 //CHECKSTYLE_OFF: LineLength
diff --git a/src/main/java/org/apache/maven/plugins/dependency/resolvers/GoOfflineMojo.java b/src/main/java/org/apache/maven/plugins/dependency/resolvers/GoOfflineMojo.java
index ab67b22..df74357 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/resolvers/GoOfflineMojo.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/resolvers/GoOfflineMojo.java
@@ -33,7 +33,6 @@
  * Goal that resolves all project dependencies, including plugins and reports and their dependencies.
  *
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
- * @version $Id$
  * @since 2.0
  */
 @Mojo( name = "go-offline", requiresDependencyResolution = ResolutionScope.TEST, threadSafe = true )
diff --git a/src/main/java/org/apache/maven/plugins/dependency/resolvers/ListMojo.java b/src/main/java/org/apache/maven/plugins/dependency/resolvers/ListMojo.java
index ad7c4dc..c4bc2ab 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/resolvers/ListMojo.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/resolvers/ListMojo.java
@@ -26,7 +26,6 @@
  * Displays the list of dependencies for this project.
  *
  * @author <a href="mailto:markhobson@gmail.com">Mark Hobson</a>
- * @version $Id$
  * @since 2.0-alpha-5
  */
 @Mojo( name = "list", requiresDependencyResolution = ResolutionScope.TEST, threadSafe = true )
diff --git a/src/main/java/org/apache/maven/plugins/dependency/resolvers/ListRepositoriesMojo.java b/src/main/java/org/apache/maven/plugins/dependency/resolvers/ListRepositoriesMojo.java
index 149a5f1..b930c3f 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/resolvers/ListRepositoriesMojo.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/resolvers/ListRepositoriesMojo.java
@@ -34,7 +34,6 @@
  * dependencies

  *

  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>

- * @version $Id: GoOfflineMojo.java 728546 2008-12-21 22:56:51Z bentmann $

  * @since 2.2

  */

 @Mojo( name = "list-repositories", requiresDependencyResolution = ResolutionScope.TEST, threadSafe = true )

diff --git a/src/main/java/org/apache/maven/plugins/dependency/resolvers/ResolveDependenciesMojo.java b/src/main/java/org/apache/maven/plugins/dependency/resolvers/ResolveDependenciesMojo.java
index 7514e09..86b595c 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/resolvers/ResolveDependenciesMojo.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/resolvers/ResolveDependenciesMojo.java
@@ -51,7 +51,6 @@
  * module names will be visible as well.
  *
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
- * @version $Id$
  * @since 2.0
  */
 //CHECKSTYLE_OFF: LineLength
@@ -134,7 +133,13 @@
         return new ResolveFileFilter( new SourcesFileMarkerHandler( this.markersDirectory ) );
     }
 
-    public String getOutput( boolean outputAbsoluteArtifactFilename, boolean outputScope, boolean sort )
+    /**
+     * @param outputAbsoluteArtifactFilename absolute artfiact filename.
+     * @param theOutputScope The output scope.
+     * @param theSort sort yes/no.
+     * @return The output.
+     */
+    public String getOutput( boolean outputAbsoluteArtifactFilename, boolean theOutputScope, boolean theSort )
     {
         StringBuilder sb = new StringBuilder();
         sb.append( "\n" );
@@ -146,7 +151,7 @@
         else
         {
             sb.append( buildArtifactListOutput( results.getResolvedDependencies(), outputAbsoluteArtifactFilename,
-                                                outputScope, sort ) );
+                                                theOutputScope, theSort ) );
         }
 
         if ( results.getSkippedDependencies() != null && !results.getSkippedDependencies().isEmpty() )
@@ -155,8 +160,8 @@
             sb.append( "The following files were skipped:\n" );
             Set<Artifact> skippedDependencies = new LinkedHashSet<Artifact>();
             skippedDependencies.addAll( results.getSkippedDependencies() );
-            sb.append( buildArtifactListOutput( skippedDependencies, outputAbsoluteArtifactFilename, outputScope,
-                                                sort ) );
+            sb.append( buildArtifactListOutput( skippedDependencies, outputAbsoluteArtifactFilename, theOutputScope,
+                                                theSort ) );
         }
 
         if ( results.getUnResolvedDependencies() != null && !results.getUnResolvedDependencies().isEmpty() )
@@ -165,8 +170,8 @@
             sb.append( "The following files have NOT been resolved:\n" );
             Set<Artifact> unResolvedDependencies = new LinkedHashSet<Artifact>();
             unResolvedDependencies.addAll( results.getUnResolvedDependencies() );
-            sb.append( buildArtifactListOutput( unResolvedDependencies, outputAbsoluteArtifactFilename, outputScope,
-                                                sort ) );
+            sb.append( buildArtifactListOutput( unResolvedDependencies, outputAbsoluteArtifactFilename, theOutputScope,
+                                                theSort ) );
         }
         sb.append( "\n" );
 
@@ -174,7 +179,7 @@
     }
 
     private StringBuilder buildArtifactListOutput( Set<Artifact> artifacts, boolean outputAbsoluteArtifactFilename,
-                                                   boolean outputScope, boolean sort )
+                                                   boolean theOutputScope, boolean theSort )
     {
         StringBuilder sb = new StringBuilder();
         List<String> artifactStringList = new ArrayList<String>();
@@ -184,7 +189,7 @@
 
             messageBuilder.a( "   " );
 
-            if ( outputScope )
+            if ( theOutputScope )
             {
                 messageBuilder.a( artifact.toString() );
             }
@@ -208,7 +213,7 @@
                 }
             }
 
-            if ( outputScope && artifact.isOptional() )
+            if ( theOutputScope && artifact.isOptional() )
             {
                 messageBuilder.a( " (optional) " );
             }
@@ -236,7 +241,7 @@
             }
             artifactStringList.add( messageBuilder.toString() + "\n" );
         }
-        if ( sort )
+        if ( theSort )
         {
             Collections.sort( artifactStringList );
         }
diff --git a/src/main/java/org/apache/maven/plugins/dependency/resolvers/ResolveDependencySourcesMojo.java b/src/main/java/org/apache/maven/plugins/dependency/resolvers/ResolveDependencySourcesMojo.java
index d1d5af5..dc5980d 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/resolvers/ResolveDependencySourcesMojo.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/resolvers/ResolveDependencySourcesMojo.java
@@ -29,7 +29,6 @@
  * Goal that resolves the project source dependencies from the repository.
  *
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
- * @version $Id$
  * @since 2.0-alpha2
  */
 //CHECKSTYLE_OFF: LineLength
diff --git a/src/main/java/org/apache/maven/plugins/dependency/resolvers/ResolvePluginsMojo.java b/src/main/java/org/apache/maven/plugins/dependency/resolvers/ResolvePluginsMojo.java
index 239c165..c0aad2b 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/resolvers/ResolvePluginsMojo.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/resolvers/ResolvePluginsMojo.java
@@ -44,7 +44,6 @@
  * Goal that resolves all project plugins and reports and their dependencies.
  *
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
- * @version $Id$
  * @since 2.0
  */
 @Mojo( name = "resolve-plugins", defaultPhase = LifecyclePhase.GENERATE_SOURCES, threadSafe = true )
diff --git a/src/main/java/org/apache/maven/plugins/dependency/utils/DependencySilentLog.java b/src/main/java/org/apache/maven/plugins/dependency/utils/DependencySilentLog.java
index 186feec..357b728 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/utils/DependencySilentLog.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/utils/DependencySilentLog.java
@@ -26,7 +26,6 @@
  * This logger implements both types of logs currently in use and turns off logs.
  * 
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
- * @version $Id$
  */
 public class DependencySilentLog
     implements Log, Logger
diff --git a/src/main/java/org/apache/maven/plugins/dependency/utils/DependencyStatusSets.java b/src/main/java/org/apache/maven/plugins/dependency/utils/DependencyStatusSets.java
index 2647f3e..ff007c2 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/utils/DependencyStatusSets.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/utils/DependencyStatusSets.java
@@ -26,7 +26,6 @@
 
 /**
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
- * @version $Id$
  */
 public class DependencyStatusSets
 {
@@ -36,11 +35,19 @@
 
     Set<Artifact> skippedDependencies = null;
 
+    /**
+     * Default ctor.
+     */
     public DependencyStatusSets()
     {
 
     }
 
+    /**
+     * @param resolved set of {@link Artifact}
+     * @param unResolved set of {@link Artifact}
+     * @param skipped set of {@link Artifact}
+     */
     public DependencyStatusSets( Set<Artifact> resolved, Set<Artifact> unResolved, Set<Artifact> skipped )
     {
         if ( resolved != null )
diff --git a/src/main/java/org/apache/maven/plugins/dependency/utils/DependencyUtil.java b/src/main/java/org/apache/maven/plugins/dependency/utils/DependencyUtil.java
index 884a932..86aec5e 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/utils/DependencyUtil.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/utils/DependencyUtil.java
@@ -267,17 +267,21 @@
         reader.close();
     }
 
-    //
-    // mainly used to parse excludes,includes configuration
-    //
+    /**
+     * mainly used to parse excludes,includes configuration
+     * @param str The string to be split.
+     * @return The result items.
+     */
     public static String[] tokenizer( String str )
     {
         return StringUtils.split( cleanToBeTokenizedString( str ), "," );
     }
 
-    //
-    // clean up configuration string before it can be tokenized
-    //
+    /**
+     * clean up configuration string before it can be tokenized
+     * @param str The str which should be cleaned.
+     * @return cleaned up string.
+     */
     public static String cleanToBeTokenizedString( String str )
     {
         String ret = "";
diff --git a/src/main/java/org/apache/maven/plugins/dependency/utils/filters/ArtifactItemFilter.java b/src/main/java/org/apache/maven/plugins/dependency/utils/filters/ArtifactItemFilter.java
index caa3933..0ce5eea 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/utils/filters/ArtifactItemFilter.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/utils/filters/ArtifactItemFilter.java
@@ -24,11 +24,15 @@
 
 /**
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
- * @version $Id$
  */
 public interface ArtifactItemFilter
 {
 
+    /**
+     * @param item {@link ArtifactItem}
+     * @return true/false.
+     * @throws ArtifactFilterException in case of an error.
+     */
     boolean isArtifactIncluded( ArtifactItem item )
         throws ArtifactFilterException;
 }
diff --git a/src/main/java/org/apache/maven/plugins/dependency/utils/filters/DestFileFilter.java b/src/main/java/org/apache/maven/plugins/dependency/utils/filters/DestFileFilter.java
index f7a198b..b19fb21 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/utils/filters/DestFileFilter.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/utils/filters/DestFileFilter.java
@@ -32,7 +32,6 @@
 
 /**
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
- * @version $Id$
  */
 public class DestFileFilter
     extends AbstractArtifactsFilter
@@ -62,11 +61,27 @@
 
     private File outputFileDirectory;
 
+    /**
+     * @param outputFileDirectory the output directory.
+     */
     public DestFileFilter( File outputFileDirectory )
     {
         this( false, false, false, false, false, false, false, false, false, false, outputFileDirectory );
     }
 
+    /**
+     * @param overWriteReleases true/false.
+     * @param overWriteSnapshots true/false.
+     * @param overWriteIfNewer true/false.
+     * @param useSubDirectoryPerArtifact true/false.
+     * @param useSubDirectoryPerType true/false.
+     * @param useSubDirectoryPerScope true/false.
+     * @param useRepositoryLayout true/false.
+     * @param removeVersion true/false.
+     * @param prependGroupId true/false.
+     * @param useBaseVersion true/false.
+     * @param outputFileDirectory the output directory.
+     */
     public DestFileFilter( boolean overWriteReleases, boolean overWriteSnapshots, boolean overWriteIfNewer,
                            boolean useSubDirectoryPerArtifact, boolean useSubDirectoryPerType,
                            boolean useSubDirectoryPerScope, boolean useRepositoryLayout, boolean removeVersion,
diff --git a/src/main/java/org/apache/maven/plugins/dependency/utils/filters/MarkerFileFilter.java b/src/main/java/org/apache/maven/plugins/dependency/utils/filters/MarkerFileFilter.java
index 9fb3e09..3a54a68 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/utils/filters/MarkerFileFilter.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/utils/filters/MarkerFileFilter.java
@@ -31,7 +31,6 @@
 
 /**
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
- * @version $Id$
  */
 public class MarkerFileFilter
     extends AbstractArtifactsFilter
@@ -44,8 +43,17 @@
 
     private boolean overWriteIfNewer;
 
+    /**
+     * The handler.
+     */
     protected final MarkerHandler handler;
 
+    /**
+     * @param overWriteReleases true/false.
+     * @param overWriteSnapshots true/false.
+     * @param overWriteIfNewer true/false.
+     * @param handler {@link MarkerHandler}
+     */
     public MarkerFileFilter( boolean overWriteReleases, boolean overWriteSnapshots, boolean overWriteIfNewer,
                              MarkerHandler handler )
     {
diff --git a/src/main/java/org/apache/maven/plugins/dependency/utils/filters/ResolveFileFilter.java b/src/main/java/org/apache/maven/plugins/dependency/utils/filters/ResolveFileFilter.java
index e48a3be..b321987 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/utils/filters/ResolveFileFilter.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/utils/filters/ResolveFileFilter.java
@@ -26,12 +26,14 @@
 
 /**
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
- * @version $Id$
  */
 public class ResolveFileFilter
     extends MarkerFileFilter
 {
 
+    /**
+     * @param handler {@link MarkerHandler}
+     */
     public ResolveFileFilter( MarkerHandler handler )
     {
         super( true, true, true, handler );
diff --git a/src/main/java/org/apache/maven/plugins/dependency/utils/markers/DefaultFileMarkerHandler.java b/src/main/java/org/apache/maven/plugins/dependency/utils/markers/DefaultFileMarkerHandler.java
index 6c792b8..c6c3364 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/utils/markers/DefaultFileMarkerHandler.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/utils/markers/DefaultFileMarkerHandler.java
@@ -27,20 +27,32 @@
 
 /**
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
- * @version $Id$
  */
 public class DefaultFileMarkerHandler
     implements MarkerHandler
 {
+    /**
+     * The artifact.
+     */
     protected Artifact artifact;
 
+    /**
+     * The marker directory.
+     */
     protected File markerFilesDirectory;
 
+    /**
+     * @param theMarkerFilesDirectory The marker directory.
+     */
     public DefaultFileMarkerHandler( File theMarkerFilesDirectory )
     {
         this.markerFilesDirectory = theMarkerFilesDirectory;
     }
 
+    /**
+     * @param theArtifact {@link Artifact}
+     * @param theMarkerFilesDirectory The marker directory.
+     */
     public DefaultFileMarkerHandler( Artifact theArtifact, File theMarkerFilesDirectory )
     {
         this.artifact = theArtifact;
diff --git a/src/main/java/org/apache/maven/plugins/dependency/utils/markers/MarkerHandler.java b/src/main/java/org/apache/maven/plugins/dependency/utils/markers/MarkerHandler.java
index ec111cb..040c019 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/utils/markers/MarkerHandler.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/utils/markers/MarkerHandler.java
@@ -24,22 +24,40 @@
 
 /**
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
- * @version $Id$
  */
 public interface MarkerHandler
 {
+    /**
+     * @return true/false.
+     * @throws MojoExecutionException in case of an error.
+     */
     boolean isMarkerSet()
         throws MojoExecutionException;
 
+    /**
+     * @throws MojoExecutionException in case of an error.
+     */
     void setMarker()
         throws MojoExecutionException;
 
+    /**
+     * @return true/false.
+     * @throws MojoExecutionException in case of an error.
+     */
     boolean clearMarker()
         throws MojoExecutionException;
 
+    /**
+     * @param artifact {@link Artifact}
+     * @return true/false.
+     * @throws MojoExecutionException in case of an error.
+     */
     boolean isMarkerOlder( Artifact artifact )
         throws MojoExecutionException;
 
+    /**
+     * @param artifact {@link Artifact}
+     */
     void setArtifact( Artifact artifact );
 
 }
diff --git a/src/main/java/org/apache/maven/plugins/dependency/utils/markers/SourcesFileMarkerHandler.java b/src/main/java/org/apache/maven/plugins/dependency/utils/markers/SourcesFileMarkerHandler.java
index 2c7da39..2134a3c 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/utils/markers/SourcesFileMarkerHandler.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/utils/markers/SourcesFileMarkerHandler.java
@@ -27,7 +27,6 @@
 
 /**
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
- * @version $Id$
  */
 public class SourcesFileMarkerHandler
     extends DefaultFileMarkerHandler
@@ -35,11 +34,19 @@
 
     boolean resolved;
 
+    /**
+     * @param markerFilesDirectory the marker files directory.
+     */
     public SourcesFileMarkerHandler( File markerFilesDirectory )
     {
         super( markerFilesDirectory );
     }
 
+    /**
+     * @param artifact {@link Artifact}
+     * @param markerFilesDirectory marker files directory.
+     * @param isResolved true/false.
+     */ 
     public SourcesFileMarkerHandler( Artifact artifact, File markerFilesDirectory, boolean isResolved )
     {
         super( artifact, markerFilesDirectory );
diff --git a/src/main/java/org/apache/maven/plugins/dependency/utils/markers/UnpackFileMarkerHandler.java b/src/main/java/org/apache/maven/plugins/dependency/utils/markers/UnpackFileMarkerHandler.java
index 343f5a3..e02f657 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/utils/markers/UnpackFileMarkerHandler.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/utils/markers/UnpackFileMarkerHandler.java
@@ -26,18 +26,27 @@
 
 /**
  * @author <a href="mailto:dbradicich@comcast.net">Damian Bradicich</a>
- * @version $Id$
  */
 public class UnpackFileMarkerHandler
     extends DefaultFileMarkerHandler
 {
+    /**
+     * The ArtifactItem.
+     */
     protected ArtifactItem artifactItem;
 
+    /**
+     * @param markerFilesDirectory The marker files directory.
+     */
     public UnpackFileMarkerHandler( File markerFilesDirectory )
     {
         super( markerFilesDirectory );
     }
 
+    /**
+     * @param artifactItem {@link ArtifactItem}
+     * @param markerFilesDirectory the marker files directory.
+     */
     public UnpackFileMarkerHandler( ArtifactItem artifactItem, File markerFilesDirectory )
     {
         this( markerFilesDirectory );
@@ -79,6 +88,9 @@
         return markerFile;
     }
 
+    /**
+     * @param artifactItem {@link #artifactItem}
+     */
     public void setArtifactItem( ArtifactItem artifactItem )
     {
         this.artifactItem = artifactItem;
@@ -89,6 +101,9 @@
         }
     }
 
+    /**
+     * @return {@link #artifactItem}
+     */
     public ArtifactItem getArtifactItem()
     {
         return this.artifactItem;
diff --git a/src/main/java/org/apache/maven/plugins/dependency/utils/translators/ArtifactTranslator.java b/src/main/java/org/apache/maven/plugins/dependency/utils/translators/ArtifactTranslator.java
index c63e7b6..c51d9fc 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/utils/translators/ArtifactTranslator.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/utils/translators/ArtifactTranslator.java
@@ -27,9 +27,13 @@
 
 /**
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
- * @version $Id$
  */
 public interface ArtifactTranslator
 {
+    /**
+     * @param artifacts set of {@link Artifact}s.
+     * @param log {@link Log}
+     * @return {@link ArtifactCoordinate}
+     */
     Set<ArtifactCoordinate> translate( Set<Artifact> artifacts, Log log );
 }
diff --git a/src/main/java/org/apache/maven/plugins/dependency/utils/translators/ClassifierTypeTranslator.java b/src/main/java/org/apache/maven/plugins/dependency/utils/translators/ClassifierTypeTranslator.java
index 27c6353..f31f523 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/utils/translators/ClassifierTypeTranslator.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/utils/translators/ClassifierTypeTranslator.java
@@ -32,7 +32,6 @@
 
 /**
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
- * @version $Id$
  */
 public class ClassifierTypeTranslator
     implements ArtifactTranslator
diff --git a/src/main/java/org/apache/maven/plugins/dependency/PurgeLocalRepositoryMojo.java b/src/main/java/org/apache/maven/plugins/dependency/PurgeLocalRepositoryMojo.java
index 18ac7b2..da2a11d 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/PurgeLocalRepositoryMojo.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/PurgeLocalRepositoryMojo.java
@@ -68,7 +68,6 @@
  * Outside of a project, remove the manually given dependencies.
  *
  * @author jdcasey
- * @version $Id$
  * @since 2.0
  */
 @Mojo( name = "purge-local-repository", threadSafe = true, requiresProject = false )
@@ -76,13 +75,11 @@
     extends AbstractMojo
 {
 
-    public static final String FILE_FUZZINESS = "file";
+    private static final String VERSION_FUZZINESS = "version";
 
-    public static final String VERSION_FUZZINESS = "version";
+    private static final String ARTIFACT_ID_FUZZINESS = "artifactId";
 
-    public static final String ARTIFACT_ID_FUZZINESS = "artifactId";
-
-    public static final String GROUP_ID_FUZZINESS = "groupId";
+    private static final String GROUP_ID_FUZZINESS = "groupId";
 
     /**
      * The Maven projects in the reactor.
@@ -363,27 +360,27 @@
     /**
      * Purges the local repository for the dependencies in the given Maven project.
      *
      * @param project Maven project.
      * @param resolvedArtifactsToPurge The artifacts that were already purged.
      * @throws MojoFailureException in case of errors during the purge.
      */
-    private void purgeLocalRepository( MavenProject project, Set<Artifact> purgedArtifacts )
+    private void purgeLocalRepository( MavenProject theProject, Set<Artifact> purgedArtifacts )
         throws MojoFailureException
     {
-        List<Dependency> dependencies = project.getDependencies();
+        List<Dependency> dependencies = theProject.getDependencies();
 
-        TransformableFilter dependencyFilter = createPurgeArtifactsFilter( project, dependencies, purgedArtifacts );
+        TransformableFilter dependencyFilter = createPurgeArtifactsFilter( theProject, dependencies, purgedArtifacts );
 
         Set<Artifact> resolvedArtifactsToPurge =
-            getFilteredResolvedArtifacts( project, dependencies, dependencyFilter );
+            getFilteredResolvedArtifacts( theProject, dependencies, dependencyFilter );
 
         if ( resolvedArtifactsToPurge.isEmpty() )
         {
-            getLog().info( "No artifacts included for purge for project: " + project.getId() );
+            getLog().info( "No artifacts included for purge for project: " + theProject.getId() );
             return;
         }
 
-        verbose( "Purging dependencies for project: " + project.getId() );
+        verbose( "Purging dependencies for project: " + theProject.getId() );
         purgeArtifacts( resolvedArtifactsToPurge );
         purgedArtifacts.addAll( resolvedArtifactsToPurge );
 
@@ -392,11 +389,11 @@
             ArtifactFilter artifactFilter = dependencyFilter.transform( new ArtifactIncludeFilterTransformer() );
             try
             {
-                reResolveArtifacts( project, resolvedArtifactsToPurge, artifactFilter );
+                reResolveArtifacts( theProject, resolvedArtifactsToPurge, artifactFilter );
             }
             catch ( ArtifactResolutionException e )
             {
-                String failureMessage = "Failed to refresh project dependencies for: " + project.getId();
+                String failureMessage = "Failed to refresh project dependencies for: " + theProject.getId();
                 MojoFailureException failure = new MojoFailureException( failureMessage );
                 failure.initCause( e );
 
@@ -404,7 +401,7 @@
             }
             catch ( ArtifactNotFoundException e )
             {
-                String failureMessage = "Failed to refresh project dependencies for: " + project.getId();
+                String failureMessage = "Failed to refresh project dependencies for: " + theProject.getId();
                 MojoFailureException failure = new MojoFailureException( failureMessage );
                 failure.initCause( e );
 
@@ -416,13 +413,13 @@
     /**
      * Purge/Delete artifacts from the local repository according to the given patterns.
      *
-     * @param inclusionPatterns
-     * @throws MojoExecutionException
+     * @param theIncludes The includes.
+     * @throws MojoExecutionException in case of an error.
      */
-    private void manualPurge( List<String> includes )
+    private void manualPurge( List<String> theIncludes )
         throws MojoExecutionException
     {
-        for ( String gavPattern : includes )
+        for ( String gavPattern : theIncludes )
         {
             if ( StringUtils.isEmpty( gavPattern ) )
             {
@@ -481,12 +478,12 @@
      * Create the includes exclude filter to use when resolving and purging dependencies Also excludes any "system"
      * scope dependencies
      *
      * @param project The Maven project.
      * @param dependencies The dependencies to use as a reference if we're excluding transitive dependencies
      * @param purgedArtifacts The artifacts already purged.
      * @return the created filter
      */
-    private TransformableFilter createPurgeArtifactsFilter( MavenProject project, List<Dependency> dependencies,
+    private TransformableFilter createPurgeArtifactsFilter( MavenProject theProject, List<Dependency> dependencies,
                                                             Set<Artifact> purgedArtifacts )
     {
         List<TransformableFilter> subFilters = new ArrayList<TransformableFilter>();
@@ -520,7 +517,7 @@
 
         if ( !actTransitively )
         {
-            subFilters.add( new DirectDependencyFilter( project.getArtifact(), dependencies ) );
+            subFilters.add( new DirectDependencyFilter( theProject.getArtifact(), dependencies ) );
         }
 
         List<String> exclusions = new ArrayList<String>( reactorProjects.size() );
@@ -554,29 +551,29 @@
     /**
      * Convert comma separated list of includes to List object
      *
-     * @param include
+     * @param theInclude The list of includes
      * @return the includes list
      */
-    private List<String> parseIncludes( String include )
+    private List<String> parseIncludes( String theInclude )
     {
-        List<String> includes = new ArrayList<String>();
+        List<String> theIncludes = new ArrayList<String>();
 
-        if ( include != null )
+        if ( theInclude != null )
         {
-            String[] elements = include.split( "," );
-            includes.addAll( Arrays.asList( elements ) );
+            String[] elements = theInclude.split( "," );
+            theIncludes.addAll( Arrays.asList( elements ) );
         }
 
-        return includes;
+        return theIncludes;
     }
 
-    private Set<Artifact> getFilteredResolvedArtifacts( MavenProject project, List<Dependency> dependencies,
+    private Set<Artifact> getFilteredResolvedArtifacts( MavenProject theProject, List<Dependency> dependencies,
                                                         TransformableFilter filter )
     {
         try
         {
             Iterable<ArtifactResult> results =
-                dependencyResolver.resolveDependencies( session.getProjectBuildingRequest(), project.getModel(),
+                dependencyResolver.resolveDependencies( session.getProjectBuildingRequest(), theProject.getModel(),
                                                         filter );
 
             Set<Artifact> resolvedArtifacts = new LinkedHashSet<Artifact>();
@@ -590,8 +587,8 @@
         }
         catch ( DependencyResolverException e )
         {
-            getLog().info( "Unable to resolve all dependencies for: " + project.getGroupId() + ":"
-                + project.getArtifactId() + ":" + project.getVersion()
+            getLog().info( "Unable to resolve all dependencies for: " + theProject.getGroupId() + ":"
+                + theProject.getArtifactId() + ":" + theProject.getVersion()
                 + ". Falling back to non-transitive mode for initial artifact resolution." );
         }
 
@@ -657,7 +654,7 @@
         }
     }
 
-    private void reResolveArtifacts( MavenProject project, Set<Artifact> artifacts, ArtifactFilter filter )
+    private void reResolveArtifacts( MavenProject theProject, Set<Artifact> artifacts, ArtifactFilter filter )
         throws ArtifactResolutionException, ArtifactNotFoundException
     {
 
@@ -704,8 +701,8 @@
             }
             message.append( "\nfor the artifact:" );
 
-            throw new ArtifactResolutionException( message.toString(), project.getArtifact(),
-                                                   project.getRemoteArtifactRepositories() );
+            throw new ArtifactResolutionException( message.toString(), theProject.getArtifact(),
+                                                   theProject.getRemoteArtifactRepositories() );
         }
     }
 
@@ -741,11 +738,17 @@
         }
     }
 
+    /**
+     * @return {@link #skip}
+     */
     public boolean isSkip()
     {
         return skip;
     }
 
+    /**
+     * @param skip {@link #skip}
+     */
     public void setSkip( boolean skip )
     {
         this.skip = skip;
@@ -363,27 +360,27 @@
      * Purges the local repository for the dependencies in the given Maven project.
      *
-     * @param project Maven project.
+     * @param theProject Maven project.
      * @param resolvedArtifactsToPurge The artifacts that were already purged.
      * @throws MojoFailureException in case of errors during the purge.
@@ -481,12 +478,12 @@
      * scope dependencies
      *
-     * @param project The Maven project.
+     * @param theProject The Maven project.
      * @param dependencies The dependencies to use as a reference if we're excluding transitive dependencies
      * @param purgedArtifacts The artifacts already purged.
diff --git a/src/main/java/org/apache/maven/plugins/dependency/fromConfiguration/ArtifactItem.java b/src/main/java/org/apache/maven/plugins/dependency/fromConfiguration/ArtifactItem.java
index 89a96c4..db215ce 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/fromConfiguration/ArtifactItem.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/fromConfiguration/ArtifactItem.java
@@ -32,7 +32,6 @@
  *
  * @since 1.0
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
- * @version $Id$
  */
 public class ArtifactItem
     implements DependableCoordinate
@@ -121,11 +120,17 @@
      */
     private String excludes;
 
+    /**
+     * Default ctor.
+     */
     public ArtifactItem()
     {
         // default constructor
     }
 
+    /**
+     * @param artifact {@link Artifact}
+     */
     public ArtifactItem( Artifact artifact )
     {
         this.setArtifact( artifact );
@@ -154,11 +159,11 @@
     }
 
     /**
      * @param artifact The artifactId to set.
      */
-    public void setArtifactId( String artifact )
+    public void setArtifactId( String theArtifact )
     {
-        this.artifactId = filterEmptyString( artifact );
+        this.artifactId = filterEmptyString( theArtifact );
     }
 
     /**
@@ -154,11 +159,11 @@
 
     /**
-     * @param artifact The artifactId to set.
+     * @param theArtifact The artifactId to set.
      */
diff --git a/src/main/java/org/apache/maven/plugins/dependency/fromDependencies/CopyDependenciesMojo.java b/src/main/java/org/apache/maven/plugins/dependency/fromDependencies/CopyDependenciesMojo.java
index f9ad5c6..239f1c9 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/fromDependencies/CopyDependenciesMojo.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/fromDependencies/CopyDependenciesMojo.java
@@ -46,7 +46,6 @@
  * Goal that copies the project dependencies from the repository to a defined location.
  *
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
- * @version $Id$
  * @since 1.0
  */
 //CHECKSTYLE_OFF: LineLength
@@ -209,15 +208,15 @@
      * @param artifact representing the object to be copied.
      * @param removeVersion specifies if the version should be removed from the file name when copying.
      * @param prependGroupId specifies if the groupId should be prepend to the file while copying.
      * @param useBaseVersion specifies if the baseVersion of the artifact should be used instead of the version.
      * @throws MojoExecutionException with a message if an error occurs.
      * @see #copyArtifact(Artifact, boolean, boolean, boolean, boolean)
      */
     protected void copyArtifact( Artifact artifact, boolean removeVersion, boolean prependGroupId,
-                                 boolean useBaseVersion )
+                                 boolean theUseBaseVersion )
         throws MojoExecutionException
     {
-        copyArtifact( artifact, removeVersion, prependGroupId, useBaseVersion, false );
+        copyArtifact( artifact, removeVersion, prependGroupId, theUseBaseVersion, false );
     }
 
     /**
@@ -227,19 +226,19 @@
      * @param artifact representing the object to be copied.
      * @param removeVersion specifies if the version should be removed from the file name when copying.
      * @param prependGroupId specifies if the groupId should be prepend to the file while copying.
      * @param useBaseVersion specifies if the baseVersion of the artifact should be used instead of the version.
      * @param removeClassifier specifies if the classifier should be removed from the file name when copying.
      * @throws MojoExecutionException with a message if an error occurs.
      * @see #copyFile(File, File)
      * @see DependencyUtil#getFormattedOutputDirectory(boolean, boolean, boolean, boolean, boolean, File, Artifact)
      */
     protected void copyArtifact( Artifact artifact, boolean removeVersion, boolean prependGroupId,
-                                 boolean useBaseVersion, boolean removeClassifier )
+                                 boolean theUseBaseVersion, boolean removeClassifier )
         throws MojoExecutionException
     {
 
         String destFileName = DependencyUtil.getFormattedFileName( artifact, removeVersion, prependGroupId,
-                                                                   useBaseVersion, removeClassifier );
+                                                                   theUseBaseVersion, removeClassifier );
 
         File destDir;
         destDir = DependencyUtil.getFormattedOutputDirectory( useSubDirectoryPerScope, useSubDirectoryPerType,
@@ -296,6 +295,10 @@
         }
     }
 
+    /**
+     * @param artifact {@link Artifact}
+     * @return {@link Artifact}
+     */
     protected Artifact getResolvedPomArtifact( Artifact artifact )
     {
         DefaultArtifactCoordinate coordinate = new DefaultArtifactCoordinate();
@@ -209,15 +208,15 @@
      * @param removeVersion specifies if the version should be removed from the file name when copying.
      * @param prependGroupId specifies if the groupId should be prepend to the file while copying.
-     * @param useBaseVersion specifies if the baseVersion of the artifact should be used instead of the version.
+     * @param theUseBaseVersion specifies if the baseVersion of the artifact should be used instead of the version.
      * @throws MojoExecutionException with a message if an error occurs.
      * @see #copyArtifact(Artifact, boolean, boolean, boolean, boolean)
@@ -227,19 +226,19 @@
      * @param removeVersion specifies if the version should be removed from the file name when copying.
      * @param prependGroupId specifies if the groupId should be prepend to the file while copying.
-     * @param useBaseVersion specifies if the baseVersion of the artifact should be used instead of the version.
+     * @param theUseBaseVersion specifies if the baseVersion of the artifact should be used instead of the version.
      * @param removeClassifier specifies if the classifier should be removed from the file name when copying.
      * @throws MojoExecutionException with a message if an error occurs.
diff --git a/src/main/java/org/apache/maven/plugins/dependency/tree/TreeMojo.java b/src/main/java/org/apache/maven/plugins/dependency/tree/TreeMojo.java
index 7ece33e..d8a4367 100644
--- a/src/main/java/org/apache/maven/plugins/dependency/tree/TreeMojo.java
+++ b/src/main/java/org/apache/maven/plugins/dependency/tree/TreeMojo.java
@@ -64,7 +64,6 @@
  * Displays the dependency tree for this project.
  *
  * @author <a href="mailto:markhobson@gmail.com">Mark Hobson</a>
- * @version $Id$
  * @since 2.0-alpha-5
  */
 @Mojo( name = "tree", requiresDependencyCollection = ResolutionScope.TEST, threadSafe = true )
@@ -291,11 +290,17 @@
         return rootNode;
     }
 
+    /**
+     * @return {@link #skip}
+     */
     public boolean isSkip()
     {
         return skip;
     }
 
+    /**
+     * @param skip {@link #skip}
+     */
     public void setSkip( boolean skip )
     {
         this.skip = skip;
@@ -330,10 +335,10 @@
     /**
      * Serializes the specified dependency tree to a string.
      *
      * @param rootNode the dependency tree root node to serialize
      * @return the serialized dependency tree
      */
-    private String serializeDependencyTree( DependencyNode rootNode )
+    private String serializeDependencyTree( DependencyNode theRootNode )
     {
         StringWriter writer = new StringWriter();
 
@@ -348,18 +353,22 @@
         {
             CollectingDependencyNodeVisitor collectingVisitor = new CollectingDependencyNodeVisitor();
             DependencyNodeVisitor firstPassVisitor = new FilteringDependencyNodeVisitor( collectingVisitor, filter );
-            rootNode.accept( firstPassVisitor );
+            theRootNode.accept( firstPassVisitor );
 
             DependencyNodeFilter secondPassFilter =
                 new AncestorOrSelfDependencyNodeFilter( collectingVisitor.getNodes() );
             visitor = new FilteringDependencyNodeVisitor( visitor, secondPassFilter );
         }
 
-        rootNode.accept( visitor );
+        theRootNode.accept( visitor );
 
         return writer.toString();
     }
 
+    /**
+     * @param writer {@link Writer}
+     * @return {@link DependencyNodeVisitor}
+     */
     public DependencyNodeVisitor getSerializingDependencyNodeVisitor( Writer writer )
     {
         if ( "graphml".equals( outputType ) )
@@ -383,20 +392,20 @@
     /**
      * Gets the graph tokens instance for the specified name.
      *
      * @param tokens the graph tokens name
      * @return the <code>GraphTokens</code> instance
      */
-    private GraphTokens toGraphTokens( String tokens )
+    private GraphTokens toGraphTokens( String theTokens )
     {
         GraphTokens graphTokens;
 
-        if ( "whitespace".equals( tokens ) )
+        if ( "whitespace".equals( theTokens ) )
         {
             getLog().debug( "+ Using whitespace tree tokens" );
 
             graphTokens = SerializingDependencyNodeVisitor.WHITESPACE_TOKENS;
         }
-        else if ( "extended".equals( tokens ) )
+        else if ( "extended".equals( theTokens ) )
         {
             getLog().debug( "+ Using extended tree tokens" );
 
@@ -330,10 +335,10 @@
      * Serializes the specified dependency tree to a string.
      *
-     * @param rootNode the dependency tree root node to serialize
+     * @param theRootNode the dependency tree root node to serialize
      * @return the serialized dependency tree
      */
@@ -383,20 +392,20 @@
      * Gets the graph tokens instance for the specified name.
      *
-     * @param tokens the graph tokens name
+     * @param theTokens the graph tokens name
      * @return the <code>GraphTokens</code> instance
      */